﻿using Blazored.LocalStorage;
using Blazor.Services;
using Blazored.Modal.Services;
using Blazor.ViewClasses;
using System.Text;
using Microsoft.JSInterop;
using Microsoft.AspNetCore.Components;
using Blazorise.DataGrid;
using ChoETL;
using Microsoft.AspNetCore.Components.Forms;
using Blazor.Modals;
using Blazored.Modal;
using System.Text.RegularExpressions;

namespace Blazor.Pages.Questions;

public partial class Questions
{
    public List<Question> questions;

    private int totalQuestion;

    [Inject]
    public NavigationManager NavigationManager { get; set; }

    [CascadingParameter]
    public IModalService Modal { get; set; }

    [Inject]
    public IDataService DataService { get; set; }
    public IWebHostEnvironment WebHostEnvironment { get; set; }

    [Inject]
    public HttpClient Http { get; set; }

    [Inject]
    public ILocalStorageService LocalStorage { get; set; }

    [Inject]
    public IJSRuntime IJSRuntime { get; set; }

    private async void OnDelete(int id)
    {
        var parameters = new ModalParameters();
        parameters.Add(nameof(Question.Q_id), id);

        var modal = Modal.Show<DeleteConfirmation>("Delete Confirmation", parameters);
        var result = await modal.Result;

        if (result.Cancelled)
        {
            return;
        }

        string apiUri = API.API_URL+"delete/question/" + id + "/" + API.TOKEN;

        using (var httpClient = new HttpClient())
        {
            var response = await httpClient.DeleteAsync(apiUri);

            if (response.IsSuccessStatusCode)
            {
                var responseBody = await response.Content.ReadAsStringAsync();
            }
            else
            {
                var errorResponse = await response.Content.ReadAsStringAsync();
            }
        }

        NavigationManager.NavigateTo("questions", true);
    }

    private async Task OnReadData(DataGridReadDataEventArgs<Question> e)
    {
        if (e.CancellationToken.IsCancellationRequested)
        {
            return;
        }

        
        var response = Http.GetFromJsonAsync<Question[]>(API.API_URL+"questions/"+API.TOKEN).Result;

        if (!e.CancellationToken.IsCancellationRequested)
        {
            questions = new List<Question>(response); // an actual data for the current page
            totalQuestion = questions.Count;
            var currentData = await LocalStorage.GetItemAsync<Question[]>("data");

            // Check if data exist in the local storage
            if (currentData == null || currentData.Length != questions.Count)
            {
                // this code add in the local storage the fake data (we load the data sync for initialize the data before load the OnReadData method)
                var originalData = Http.GetFromJsonAsync<Question[]>(API.API_URL+"chapters/"+API.TOKEN).Result;
                await LocalStorage.SetItemAsync("data", originalData);
            }
        }
    }

    private async Task Export()
    {
        StringBuilder sb = new StringBuilder();
        HttpResponseMessage response = await Http.GetAsync(API.API_URL+"questionsExport/"+API.TOKEN);
        var json = await response.Content.ReadAsStringAsync();
        using (var jsonFile = ChoJSONReader.LoadText(json))
        {
            using (var csvFile = new ChoCSVWriter(sb).WithFirstLineHeader())
            {
                csvFile.Write(jsonFile);
            }
        }

        var sentFile = new MemoryStream(Encoding.Unicode.GetBytes(sb.ToString()));
        using (var streamRef = new DotNetStreamReference(stream: sentFile))
        {
            await IJSRuntime.InvokeVoidAsync("downloadFileFromStream", "data.csv", streamRef);
        }
    }

    private async Task SingleUpload(InputFileChangeEventArgs e)
    {
        using (MemoryStream ms = new MemoryStream())
        {
            await e.File.OpenReadStream().CopyToAsync(ms);
            var bytes = ms.ToArray();
            string s = Encoding.UTF8.GetString(bytes);

            s = s.Replace("\r\n", "\n");
            var rows = s.Split('\n');
            rows = rows.Skip(1).ToArray();

            foreach (var row in rows)
            {
                var field = row.Split(';');
                var formData = new List<KeyValuePair<string, string>>();
                formData.Add(new KeyValuePair<string, string>("content", field[0]));
                formData.Add(new KeyValuePair<string, string>("answerContent1", field[2]));
                formData.Add(new KeyValuePair<string, string>("answerContent2", field[3]));
                formData.Add(new KeyValuePair<string, string>("answerContent3", field[4]));
                formData.Add(new KeyValuePair<string, string>("answerContent4", field[5]));
                formData.Add(new KeyValuePair<string, string>("idanswergood", field[6]));

                string apiUri = API.API_URL+"chapters/name/"+field[1] + "/" + API.TOKEN;


                var response = await Http.GetAsync(apiUri);

                if (response.IsSuccessStatusCode)
                {
                    var responseBody = await response.Content.ReadAsStringAsync();
                    Match match = Regex.Match(responseBody, @"\d+");
                    int result = int.Parse(match.Value);
                    formData.Add(new KeyValuePair<string, string>("idchapter", result.ToString()));
                }
                else
                {
                    var errorResponse = await response.Content.ReadAsStringAsync();
                    formData.Add(new KeyValuePair<string, string>("idchapter", "Unknown_Chapter_Error"));
                }

                var formContent = new FormUrlEncodedContent(formData);
                apiUri = API.API_URL+"add/questions/"+API.TOKEN;

                response = await Http.PostAsync(apiUri, formContent);

                if (response.IsSuccessStatusCode)
                {
                    var responseBody = await response.Content.ReadAsStringAsync();
                }
                else
                {
                    var errorResponse = await response.Content.ReadAsStringAsync();
                }
            }
        }
    }
}

